@@ -72,8 +72,8 @@ struct _ClutterDragActionPrivate
 {
   ClutterActor *stage;
 
-  gfloat drag_threshold_x;
-  gfloat drag_threshold_y;
+  gfloat x_drag_threshold;
+  gfloat y_drag_threshold;
   ClutterActor *drag_handle;
   ClutterDragAxis drag_axis;
 
@@ -99,9 +99,8 @@ enum
 {
   PROP_0,
 
-  PROP_DRAG_THRESHOLD_X,
-  PROP_DRAG_THRESHOLD_Y,
-  PROP_DRAG_THRESHOLD,
+  PROP_X_DRAG_THRESHOLD,
+  PROP_Y_DRAG_THRESHOLD,
   PROP_DRAG_HANDLE,
   PROP_DRAG_AXIS,
 
@@ -191,8 +190,8 @@ emit_drag_motion (ClutterDragAction *action,
 
   if (priv->emit_delayed_press)
     {
-      if (ABS (delta_x) >= priv->drag_threshold_x ||
-          ABS (delta_y) >= priv->drag_threshold_y)
+      if (ABS (delta_x) >= priv->x_drag_threshold ||
+          ABS (delta_y) >= priv->y_drag_threshold)
         {
           priv->emit_delayed_press = FALSE;
 
@@ -311,7 +310,7 @@ on_button_press (ClutterActor      *actor,
                                        &priv->transformed_press_x,
                                        &priv->transformed_press_y);
 
-  if (priv->drag_threshold_x == 0 || priv->drag_threshold_y == 0)
+  if (priv->x_drag_threshold == 0 || priv->y_drag_threshold == 0)
     emit_drag_begin (action, actor, event);
   else
     priv->emit_delayed_press = TRUE;
@@ -381,16 +380,14 @@ clutter_drag_action_set_property (GObject      *gobject,
 
   switch (prop_id)
     {
-    case PROP_DRAG_THRESHOLD_X:
-      clutter_drag_action_set_drag_threshold_x (action, g_value_get_uint (value));
+    case PROP_X_DRAG_THRESHOLD:
+      clutter_drag_action_set_drag_threshold (action, g_value_get_uint (value),
+                                              action->priv->y_drag_threshold);
       break;
 
-    case PROP_DRAG_THRESHOLD_Y:
-      clutter_drag_action_set_drag_threshold_y (action, g_value_get_uint (value));
-      break;
-
-    case PROP_DRAG_THRESHOLD:
-      clutter_drag_action_set_drag_threshold (action, g_value_get_uint (value));
+    case PROP_Y_DRAG_THRESHOLD:
+      clutter_drag_action_set_drag_threshold (action, action->priv->x_drag_threshold,
+                                              g_value_get_uint (value));
       break;
 
     case PROP_DRAG_HANDLE:
@@ -416,17 +413,12 @@ clutter_drag_action_get_property (GObject    *gobject,
 
   switch (prop_id)
     {
-    case PROP_DRAG_THRESHOLD_X:
-      g_value_set_uint (value, priv->drag_threshold_x);
+    case PROP_X_DRAG_THRESHOLD:
+      g_value_set_uint (value, priv->x_drag_threshold);
       break;
 
-    case PROP_DRAG_THRESHOLD_Y:
-      g_value_set_uint (value, priv->drag_threshold_y);
-      break;
-
-    case PROP_DRAG_THRESHOLD:
-      g_value_set_uint (value, MIN(priv->drag_threshold_x,
-                                   priv->drag_threshold_y));
+    case PROP_Y_DRAG_THRESHOLD:
+      g_value_set_uint (value, priv->y_drag_threshold);
       break;
 
     case PROP_DRAG_HANDLE:
@@ -486,63 +478,46 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
   klass->drag_motion = clutter_drag_action_real_drag_motion;
 
   /**
-   * ClutterDragAction:drag-threshold-x:
+   * ClutterDragAction:x-drag-threshold:
    *
    * The horizontal threshold, in pixels, that begins a drag action
    *
    * When set to a non-zero value, #ClutterDragAction will only emit
-   * #ClutterDragAction::drag-begin if the pointer has moved at least
-   * of the given amount of pixels horizontally since the button press event
+   * #ClutterDragAction::drag-begin if the pointer has moved
+   * horizontally at least of the given amount of pixels since
+   * the button press event
    *
    * Since: 1.4
    */
-  pspec = g_param_spec_uint ("drag-threshold-x",
-                             P_("Drag Threshold X"),
+  pspec = g_param_spec_uint ("x-drag-threshold",
+                             P_("Horizontal Drag Threshold"),
                              P_("The horizontal amount of pixels required to start dragging"),
                              0, G_MAXUINT,
                              0,
                              CLUTTER_PARAM_READWRITE);
-  obj_props[PROP_DRAG_THRESHOLD_X] = pspec;
-  g_object_class_install_property (gobject_class, PROP_DRAG_THRESHOLD_X, pspec);
+  obj_props[PROP_X_DRAG_THRESHOLD] = pspec;
+  g_object_class_install_property (gobject_class, PROP_X_DRAG_THRESHOLD, pspec);
 
   /**
-   * ClutterDragAction:drag-threshold-y:
+   * ClutterDragAction:y-drag-threshold:
    *
    * The vertical threshold, in pixels, that begins a drag action
    *
    * When set to a non-zero value, #ClutterDragAction will only emit
-   * #ClutterDragAction::drag-begin if the pointer has moved at least
-   * of the given amount of pixels vertically since the button press event
+   * #ClutterDragAction::drag-begin if the pointer has moved
+   * vertically at least of the given amount of pixels since
+   * the button press event
    *
    * Since: 1.4
    */
-  pspec = g_param_spec_uint ("drag-threshold-y",
-                             P_("Drag Threshold Y"),
+  pspec = g_param_spec_uint ("y-drag-threshold",
+                             P_("Vertical Drag Threshold"),
                              P_("The vertical amount of pixels required to start dragging"),
                              0, G_MAXUINT,
                              0,
                              CLUTTER_PARAM_READWRITE);
-  obj_props[PROP_DRAG_THRESHOLD_Y] = pspec;
-  g_object_class_install_property (gobject_class, PROP_DRAG_THRESHOLD_Y, pspec);
-
-  /**
-   * ClutterDragAction:drag-threshold:
-   *
-   * The threshold, in pixels, that begins a drag action
-   *
-   * Setting this property sets both :drag-threshold-x and :drag-threshold-y
-   * properties. The value of this property is the minimum of those.
-   *
-   * Since: 1.4
-   */
-  pspec = g_param_spec_uint ("drag-threshold",
-                             P_("Drag Threshold"),
-                             P_("The amount of pixels required to start dragging"),
-                             0, G_MAXUINT,
-                             0,
-                             CLUTTER_PARAM_READWRITE);
-  obj_props[PROP_DRAG_THRESHOLD] = pspec;
-  g_object_class_install_property (gobject_class, PROP_DRAG_THRESHOLD, pspec);
+  obj_props[PROP_Y_DRAG_THRESHOLD] = pspec;
+  g_object_class_install_property (gobject_class, PROP_Y_DRAG_THRESHOLD, pspec);
 
   /**
    * ClutterDragAction:drag-handle:
@@ -594,7 +569,8 @@ clutter_drag_action_class_init (ClutterDragActionClass *klass)
    * starts the dragging
    *
    * The emission of this signal can be delayed by using the
-   * #ClutterDragAction:drag-threshold property
+   * #ClutterDragAction:x-drag-threshold and
+   * #ClutterDragAction:y-drag-threshold properties
    *
    * Since: 1.4
    */
@@ -704,144 +680,66 @@ clutter_drag_action_new (void)
   return g_object_new (CLUTTER_TYPE_DRAG_ACTION, NULL);
 }
 
-/**
- * clutter_drag_action_set_drag_threshold_x:
- * @action: a #ClutterDragAction
- * @threshold: a distance, in pixels
- *
- * Sets the drag horizontal threshold that must be cleared by the pointer
- * before @action can begin the dragging
- *
- * Since: 1.4
- */
-void
-clutter_drag_action_set_drag_threshold_x (ClutterDragAction *action,
-                                          guint              threshold_x)
-{
-  ClutterDragActionPrivate *priv;
-
-  g_return_if_fail (CLUTTER_IS_DRAG_ACTION (action));
-
-  priv = action->priv;
-
-  if (priv->drag_threshold_x == threshold_x)
-    return;
-
-  priv->drag_threshold_x = threshold_x;
-
-  _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_DRAG_THRESHOLD_X]);
-  if (priv->drag_threshold_x < priv->drag_threshold_y) {
-    _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_DRAG_THRESHOLD]);
-  }
-}
-
-/**
- * clutter_drag_action_set_drag_threshold_y:
- * @action: a #ClutterDragAction
- * @threshold: a distance, in pixels
- *
- * Sets the vertical drag threshold that must be cleared by the pointer
- * before @action can begin the dragging
- *
- * Since: 1.4
- */
-void
-clutter_drag_action_set_drag_threshold_y (ClutterDragAction *action,
-                                          guint              threshold_y)
-{
-  ClutterDragActionPrivate *priv;
-
-  g_return_if_fail (CLUTTER_IS_DRAG_ACTION (action));
-
-  priv = action->priv;
-
-  if (priv->drag_threshold_y == threshold_y)
-    return;
-
-  priv->drag_threshold_y = threshold_y;
-
-  _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_DRAG_THRESHOLD_Y]);
-  if (priv->drag_threshold_y < priv->drag_threshold_x) {
-    _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_DRAG_THRESHOLD]);
-  }
-}
-
 /**
  * clutter_drag_action_set_drag_threshold:
  * @action: a #ClutterDragAction
  * @threshold: a distance, in pixels
  *
- * Sets the both horizontal and vertical drag thresholds that must be cleared
- * by the pointer before @action can begin the dragging
+ * Sets the horizontal and vertical drag thresholds that must be
+ * cleared by the pointer before @action can begin the dragging
  *
  * Since: 1.4
  */
 void
 clutter_drag_action_set_drag_threshold (ClutterDragAction *action,
-                                        guint              threshold)
+                                        guint              x_threshold,
+					guint              y_threshold)
 {
+  ClutterDragActionPrivate *priv;
+
   g_return_if_fail (CLUTTER_IS_DRAG_ACTION (action));
 
-  g_object_freeze_notify (G_OBJECT (action));
+  priv = action->priv;
 
-  clutter_drag_action_set_drag_threshold_x(action, threshold);
-  clutter_drag_action_set_drag_threshold_y(action, threshold);
+  if (priv->x_drag_threshold != x_threshold)
+    {
+      priv->x_drag_threshold = x_threshold;
 
-  g_object_thaw_notify (G_OBJECT (action));
-}
+      _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_X_DRAG_THRESHOLD]);
+    }
 
-/**
- * clutter_drag_action_get_drag_threshold_x:
- * @action: a #ClutterDragAction
- *
- * Retrieves the value set by clutter_drag_action_set_drag_threshold_x()
- *
- * Return value: the drag threshold value, in pixels
- *
- * Since: 1.4
- */
-guint
-clutter_drag_action_get_drag_threshold_x (ClutterDragAction *action)
-{
-  g_return_val_if_fail (CLUTTER_IS_DRAG_ACTION (action), 0);
+  if (priv->y_drag_threshold != y_threshold)
+    {
+      priv->y_drag_threshold = y_threshold;
 
-  return action->priv->drag_threshold_x;
-}
-
-/**
- * clutter_drag_action_get_drag_threshold_y:
- * @action: a #ClutterDragAction
- *
- * Retrieves the value set by clutter_drag_action_set_drag_threshold_y()
- *
- * Return value: the drag threshold value, in pixels
- *
- * Since: 1.4
- */
-guint
-clutter_drag_action_get_drag_threshold_y (ClutterDragAction *action)
-{
-  g_return_val_if_fail (CLUTTER_IS_DRAG_ACTION (action), 0);
-
-  return action->priv->drag_threshold_y;
+      _clutter_notify_by_pspec (G_OBJECT (action), obj_props[PROP_Y_DRAG_THRESHOLD]);
+    }  
 }
 
 /**
  * clutter_drag_action_get_drag_threshold:
  * @action: a #ClutterDragAction
+ * @x_threshold: (out): return location for the horizontal drag
+ *   threshold value, in pixels
+ * @y_threshold: (out): return location for the vertical drag
+ *   threshold value, in pixels
  *
- * Retrieves the value set by clutter_drag_action_set_drag_threshold()
- *
- * Return value: the drag threshold value, in pixels
+ * Retrieves the values set by clutter_drag_action_set_drag_threshold()
  *
  * Since: 1.4
  */
-guint
-clutter_drag_action_get_drag_threshold (ClutterDragAction *action)
+void
+clutter_drag_action_get_drag_threshold (ClutterDragAction *action,
+                                        guint             *x_threshold,
+					guint             *y_threshold)
 {
-  g_return_val_if_fail (CLUTTER_IS_DRAG_ACTION (action), 0);
+  g_return_if_fail (CLUTTER_IS_DRAG_ACTION (action));
 
-  return MIN(action->priv->drag_threshold_x, action->priv->drag_threshold_y);
+  if (x_threshold)
+    *x_threshold = action->priv->x_drag_threshold;
+
+  if (y_threshold)
+    *y_threshold = action->priv->y_drag_threshold;    
 }
 
 /**
