@@ -386,6 +386,13 @@ clutter_stage_realize (ClutterActor *self)
    */
   if (is_realized)
     {
+	//MAEMO5 PR-1.3 FIX.//
+	// reverting these rows back to git: 568c29ba491e4a6b3bef426be528d7246110011c
+	CLUTTER_ACTOR_SET_FLAGS (self, CLUTTER_ACTOR_REALIZED);
+	clutter_stage_ensure_current (CLUTTER_STAGE (self));
+	return;
+	//MAEMO5 PR-1.3 FIX.//
+
       ClutterBackend *backend = clutter_get_default_backend ();
       GError *error = NULL;
 
